@@ -119,7 +119,7 @@ char* webauth(char* url, char* proxy, char* port, char* user, char* pass, char**
         msg = NULL;
     }
 
-/*Authorization request*/
+/* Authorization request */
 
     msa_debug("Creating a message object\n");
     msg = dbus_message_new_method_call(SYSNOTE_NAME, /* destination */
@@ -201,18 +201,17 @@ void receive(char** url, char* client_id)
     char **response = NULL;
     int attempts = 0;
     int len;
-
+    GMainContext *context;
+    
     msa_debug("Listening for signals for %s\n", client_id);
 
     /* initialise the errors */
     dbus_error_init(&err);
 
-    GMainContext *context;
     context = g_main_context_new();
     msa_debug("Create context\n");
 
-    /* connect to the bus and check for errors */
-    
+    /* connect to the bus and check for errors */    
     msa_debug("Create connection\n");
     conn = dbus_bus_get_private(DBUS_BUS_SESSION, &err);
     msa_debug("Setup connection\n");
@@ -224,7 +223,7 @@ void receive(char** url, char* client_id)
     }
 
     if (NULL == conn) { 
-	g_main_context_unref(context);
+        g_main_context_unref(context);
         return;
     }
 
@@ -235,13 +234,13 @@ void receive(char** url, char* client_id)
     if (dbus_error_is_set(&err)) { 
         fprintf(stderr, "Match Error (%s)\n", err.message);
         dbus_connection_close(conn);
-	g_main_context_unref(context);
+        g_main_context_unref(context);
         return; 
     }
     msa_debug("Match rule sent\n");
 
     /* loop listening for signals being emmitted */
-    /* wait wile webauth application start */
+    /* wait wile webauth application start       */
     sleep(3);
     while (1) {
         msa_debug("wait response\n");
@@ -266,9 +265,7 @@ void receive(char** url, char* client_id)
             continue;
         }
 
-        /* check if the message is a signal from the
-         * correct interface and with the correct name
-         */
+        /* check if the message is a signal from the correct interface and with the correct name */
         if (dbus_message_is_signal(msg, SYSNOTE_NAME, DRIVER_ID)) {
          
             /* read the parameters */
@@ -289,10 +286,10 @@ void receive(char** url, char* client_id)
                         *url = g_strdup(response[1]);
                     } else {
                         dbus_free_string_array(response);
-                        dbus_message_unref(msg); 	
+                        dbus_message_unref(msg);
                         continue;
                     }
-                    dbus_free_string_array(response); 	
+                    dbus_free_string_array(response);
                 }
             }
 
@@ -303,33 +300,7 @@ void receive(char** url, char* client_id)
         /* free the message */
         dbus_message_unref(msg);
     }
-/*
-   // create a signal & check for errors 
-   msg = dbus_message_new_signal(SYSNOTE_OPATH, // object name of the signal
-                                 SYSNOTE_NAME, // interface name of the signal
-                                 SYSNOTE_SIGNAL_SHUTDOWN); // name of the signal
-   if (NULL == msg) 
-   { 
-      fprintf(stderr, "Message Null\n"); 
-      dbus_connection_unref(conn);
-      return;
-   }
 
- 
-   // send the message and flush the connection
-   if (!dbus_connection_send(conn, msg, NULL)) {
-      fprintf(stderr, "Out Of Memory!\n");
-      dbus_message_unref(msg);
-      dbus_connection_unref(conn); 
-      return;
-   }
-   dbus_connection_flush(conn);
-   
-   printf("Signal Sent\n");
-  
-   // free the message 
-   dbus_message_unref(msg);
-*/
    dbus_connection_close(conn); 
    g_main_context_unref(context);
 }
