@@ -23,13 +23,13 @@
 #include "driver.h"
 
 #ifdef DEBUG
-#	define msa_xmlDocDump(F,D) xmlDocDump(F,D)
+#       define msa_xmlDocDump(F,D) xmlDocDump(F,D)
 #else
-#	define msa_xmlDocDump(F,D)
+#       define msa_xmlDocDump(F,D)
 #endif
 
 #define XSL_CONFIG_DIR DATADIR"/"
-#define NOT_ESCAPE "!\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[]^_`abcdefghijklmnopqrstuvwxyz{|}~"
+#define NOT_ESCAPE "!\"$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[]^_`abcdefghijklmnopqrstuvwxyz{|}~"
 
 
 #define REGEXP_PARAM "regexp"
@@ -43,8 +43,9 @@ CTF_TEST_DATA_FILE_NAME_DECL;
 #endif
 
 static int global_req = 0;
+#ifdef DEBUG
 static int global_get = 0;
-
+#endif
 
 /**
  * Allocate memory
@@ -114,8 +115,8 @@ int process_inner_request(struct ProfileData *pr, xmlDocPtr inner_req)
         msa_xmlDocDump(stderr, inner_request);
         msa_debug("INNER RESPONSE\n");
         msa_xmlDocDump(stderr, inner_response);
-        /*TODO        
-          Check if error code = 6 sleep(1) and try request
+        /*
+           TODO Check if error code = 6 sleep(1) and try request
         */
         tmp_node =  xpath_get_node(XPATH_TAG_ERROR_CODE, inner_response);
         if (tmp_node != NULL){
@@ -162,9 +163,6 @@ int process_inner_request(struct ProfileData *pr, xmlDocPtr inner_req)
 
 int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* response)
 {   
-    msa_debug("\n\nRequest in process");
-    msa_xmlDocDump(stdout, request);
-
     xmlDocPtr inner_req = NULL;
     xmlDocPtr tmp_doc = NULL;
     xmlDocPtr server_response = NULL, resp = NULL, err_resp = NULL;
@@ -182,6 +180,7 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
     int http_code = 0;
     int resp_code = 0;
     int data_size = 0;
+    struct UpFile *file;
 
     msa_debug("START process_request");
     msa_xmlDocDump(stdout, request);
@@ -193,16 +192,16 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
             parser = g_strconcat(XSL_CONFIG_DIR, tmp, NULL);
             g_free(tmp);
         } else {          
-            /*use standart parser*/
+            /* use standart parser */
             parser = g_strconcat(XSL_CONFIG_DIR, "parser.xsl", NULL);       
         }
 
-        /*create inner request*/
+        /* create inner request */
         inner_req = apply_parser(request, parser, pr);
         g_free(parser);
         msa_xmlDocDump(stdout, inner_req);
         
-        /*unknown request */
+        /* unknown request */
         if (xpath_get_node("//InnerRequest", inner_req) == NULL){
             *response = xmlCopyDoc(inner_req, 1);
             xmlFreeDoc(inner_req);
@@ -263,14 +262,14 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
                 g_strfreev(post_data);
             } else if(g_strcmp0(http_type, "upload") == 0){
                 msa_debug("UPLOADING...");
-                struct UpFile *file = (struct UpFile *)malloc(sizeof (struct UpFile));
+                file = (struct UpFile *)malloc(sizeof (struct UpFile));
                 node = xpath_get_node("//InnerRequest/name", inner_req);
                 file->name = (gchar*)xmlNodeGetContent(node);
                 node = xpath_get_node("//InnerRequest/file", inner_req);
                 file->file_path = (gchar*)xmlNodeGetContent(node);
                 node = xpath_get_node("//InnerRequest/file_name", inner_req);
                 file->file_name = (gchar*)xmlNodeGetContent(node);
-                
+
                 post_data = g_strsplit_set(url, "?", 2);
                 if(post_data[1] != NULL)
                     file->params = g_strsplit_set(post_data[1], "&=", 100);
@@ -297,13 +296,13 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
 
         msa_xmlDocDump(stdout, inner_req);
 
-        /*Parse server response*/
+        /* Parse server response */
         node = xpath_get_node("//InnerRequest/parser", inner_req);
         if (node != NULL){
             parser_type = (gchar*)xmlGetProp(node, BAD_CAST "type");
             tmp = (gchar*)xmlNodeGetContent(node);
 
-            if(http_code < 300 || (http_code == 400 && g_strcmp0(parser_type, PARSER_JSON) == 0)){
+            if(http_code < 300){
                 if (g_strcmp0(parser_type, PARSER_JSON) == 0) {
                     json_parser(inner_req, pr, data, 0, &resp_str);
                     g_free(data);
@@ -365,7 +364,7 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
             xmlFreeDoc(inner_req);
 
         }
-        /*Search for requests*/
+        /* Search for requests */
         if (resp == NULL && err_resp != NULL)
             resp = xmlCopyDoc(err_resp, 1);
         if (resp != NULL){
@@ -387,10 +386,11 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
 
 xmlDocPtr apply_parser(xmlDocPtr request, gchar* parser, struct ProfileData *pr)
 {
-    msa_debug("Aply parser: %s", parser);
     xmlDocPtr proc = NULL; 
     xsltStylesheetPtr cur = NULL;
     gchar **params;
+
+    msa_debug("Aply parser: %s", parser);
     cur = xsltParseStylesheetFile((xmlChar*)parser);
 
     if(pr != NULL){
@@ -431,129 +431,92 @@ int request(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
     msa_debug("%s:%d:%s(): REQ %d\n", __FILE__, __LINE__, __FUNCTION__, global_req);
     msa_xmlDocDump(stdout, reqXml);
     node = xpath_get_node(XPATH_TAG_REQUEST, reqXml);
-    if(node != NULL)
+    if(node != NULL){
         no_auth = (gchar*)xmlGetProp(node, BAD_CAST "noAuthorize");
-    else {
+    } else {
         error_message(DRV_REQ_ERROR_CODE, doc, DRV_REQ_ERROR, "request not found");
         return 0;
     }
     func_val = (gchar*)get_req_function(reqXml);
     if (g_strcmp0(func_val, SET_SETTINGS) != 0
-        && g_strcmp0(func_val, GET_SETTINGS) != 0)
-        if(no_auth == NULL || g_strcmp0(no_auth, "true") != 0)
-            init_status = initialization(cp);
-    g_free(func_val);
-
-    if (init_status != 0) {
-        msa_debug("init_status = %d", init_status);
-        if (init_status == 2){
-            error_message(DRV_NETW_ERROR_CODE, doc, DRV_NETW_ERROR, "");
-            return 0;
-        }
-        if(init_status == 1) {
-            error_message(DRV_AUTH_ERROR_CODE, doc, DRV_AUTH_ERROR, "");
-            return 0;
+        && g_strcmp0(func_val, GET_SETTINGS) != 0
+        && g_strcmp0(func_val, GET_LIST_METHODS) != 0){
+        g_free(func_val);
+        if(g_strcmp0(no_auth, "true") != 0 && profile_check(cp) == 1){
+            if(authorize(cp, doc) == 0)
+                init_status = 1;
+            else
+                return 0;
         }
     }
+
     if (process_request(cp, reqXml, doc) == 1){
         error_message(DRV_REQ_ERROR_CODE, doc, DRV_REQ_ERROR, "");
         return 0;
     }
 
-    node = xpath_get_node(XPATH_TAG_NOTERROR, *doc);
-    if (node != NULL){
-        if(init_status == 3) {
-            xmlSetProp(node, BAD_CAST "authorized", BAD_CAST "true");
-        }
-        if(init_status == 0) {
-            xmlSetProp(node, BAD_CAST "authorized", BAD_CAST "false");
-        }
-    }                 
-
     node = xpath_get_node(XPATH_TAG_ERROR_CODE, *doc);
     if (node != NULL){
-        msa_debug("error occured");
         error_code = (gchar *)xmlNodeGetContent(node);
+        msa_debug("error occured: code = %s", error_code);
         if(g_strcmp0(error_code, DRV_AUTH_ERROR_CODE) == 0){
-            if(no_auth == NULL || g_strcmp0(no_auth, "true") != 0) {
-                if (authorize(cp) == 0) {
-                    xmlFreeDoc(*doc);
+            if(g_strcmp0(no_auth, "true") != 0) {
+                xmlFreeDoc(*doc);
+                if (authorize(cp, doc) == 0) {
+                    init_status = 1;
                     process_request(cp, reqXml, doc);
-                    node = xpath_get_node(XPATH_TAG_NOTERROR, *doc);
-                    if (node != NULL)
-                        xmlSetProp(node, BAD_CAST "authorized", BAD_CAST "true");
                 }
             }
         } else if(g_strcmp0(error_code, DRV_SERVER_BUSY_CODE) == 0){
             xmlFreeDoc(*doc);
             sleep(1);
             process_request(cp, reqXml, doc);
-            if(init_status == 3) {
-                xmlSetProp(node, BAD_CAST "authorized", BAD_CAST "true");
-            }
         }
-
-        g_free(error_code);
-            
+        g_free(error_code);            
     }
-    if(no_auth != NULL)
-        g_free(no_auth);
+
+    node = xpath_get_node(XPATH_TAG_NOTERROR, *doc);
+    if (node != NULL){
+        if(init_status)
+            xmlSetProp(node, BAD_CAST "authorized", BAD_CAST "true");
+        else
+            xmlSetProp(node, BAD_CAST "authorized", BAD_CAST "false");
+    }                 
+
+    g_free(no_auth);
     return 0;
 }
 
 /**
- * Perform authorization
- *
- * @param cp - current profile settings
- * @return 0 on success or 1 otherwise.
- */
-int initialization(struct ProfileData *cp)
-{
-    msa_debug("init START");
-
-    int auth_status = 0;
-
-    if(profile_check(cp) == 1) {
-
-        g_print("%s: authorization\n", DRIVER_ID);
-        auth_status = authorize(cp);
-        if (auth_status != 0 ) {
-            msa_debug("dr_fb: Could not get remixmid, remixsid, auth_status = %d \n", auth_status); 
-            return auth_status;
-        }
-        return 3;
-    }
-    msa_debug("init END");
-    return 0;
-}
-
-/**
- * Authorization (get remixsid and remixmid for future requests)
+ * Authorization
  *
  * @param cp - current profile
  * @return 0 on success or 1 otherwise.
  */
-int authorize(struct ProfileData *cp)
+int authorize(struct ProfileData *cp, xmlDocPtr* response)
 {
-    int ret_code = 0;
+    xmlDocPtr request = NULL;
 
     if (cp == NULL){
         msa_debug("can't authorize, no profile!");
         return 1;
-    }
-
-    xmlDocPtr request = NULL, response = NULL;
+    }    
+    
     request = xmlParseDoc((xmlChar*)AUTH_REQUEST);    
-    if(process_request(cp, request, &response) == 1){
+    if(process_request(cp, request, response) == 1){
         xmlFreeDoc(request);
         return 1;
     }
 
-    ret_code = profile_update(cp, response);
-
+    if(profile_update(cp, *response) == 1){
+        msa_debug("authorization error");
+        xmlFreeDoc(request);
+        return 1;
+    }
+    
+    xmlFreeDoc(*response);
     xmlFreeDoc(request);
-    xmlFreeDoc(response);        
-    return ret_code;
+    return 0;
 }
 
 
@@ -565,45 +528,53 @@ int authorize(struct ProfileData *cp)
  */
 gchar* call_webauth(gchar* url, struct ProfileData *cp)
 {
-#ifdef TEST
-info_proxy = CTF_TEST_DATA("PROXY");
-info_port = atoi(CTF_TEST_DATA("PORT"));
-#endif
+    gchar* back_url = NULL;
+    gchar* proxy = NULL;
+    gint port;
+    gboolean hasProxy;
+    GConfClient* client;
+    gchar* sPort;
+    char *patterns[] = {TITLE_PARAM, NULL, ACCOUNT_ID_PARAM, NULL, REGEXP_PARAM, LOGIN_SUCCESS, CLIENT_ID_PARAM, DRIVER_ID};
+    char **patt_arr;
 
     msa_debug("call_webauth: START");
-    gchar* back_url = NULL;
-    gchar *proxy = info_proxy;
-    gint port = info_port;
 
-    if (proxy == NULL)
-    {
-	    GConfClient *client = gconf_client_get_default ();
-	    gboolean hasProxy = gconf_client_get_bool (client, GCONF_PROXY_USE, NULL);
-	    msa_debug("%s:%d:%s: hasProxy=%d", __FILE__, __LINE__, __FUNCTION__, hasProxy);
-	    if (hasProxy) {
-	        proxy = gconf_client_get_string (client, GCONF_PROXY_HOST, NULL);
-	        port = gconf_client_get_int (client, GCONF_PROXY_PORT, NULL);
-	        msa_debug("%s:%d:%s: host=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, proxy, port);
-	    }
-	    g_object_unref(client);
+#   ifdef TEST
+        info_proxy = CTF_TEST_DATA("PROXY");
+        info_port = atoi(CTF_TEST_DATA("PORT"));
+#   endif
+    proxy = info_proxy;
+    port = info_port;
+
+    if (proxy == NULL) {
+            client = gconf_client_get_default();
+            hasProxy = gconf_client_get_bool(client, GCONF_PROXY_USE, NULL);
+            msa_debug("%s:%d:%s: hasProxy=%d", __FILE__, __LINE__, __FUNCTION__, hasProxy);
+            if (hasProxy) {
+                proxy = gconf_client_get_string(client, GCONF_PROXY_HOST, NULL);
+                port = gconf_client_get_int(client, GCONF_PROXY_PORT, NULL);
+                msa_debug("%s:%d:%s: host=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, proxy, port);
+            }
+            g_object_unref(client);
     }
-    gchar* sPort = g_strdup_printf("%d", port);
+    sPort = g_strdup_printf("%d", port);
 
     msa_debug("%s:%d:%s: use proxy=%s:%d", __FILE__, __LINE__, __FUNCTION__, proxy, port);
 
-    if (cp == NULL){
+    if (cp == NULL) {
         msa_debug("can't authorize, no profile!");
         return NULL;
     }
-    if (url == NULL){
+    if (url == NULL) {
         msa_debug("can't authorize, no url!");
         return NULL;
     }
 
-
     msa_debug("Try call webauth with %s = %s", CLIENT_ID_PARAM, cp->id);
-    char *patterns[] = { REGEXP_PARAM, LOGIN_SUCCESS, TITLE_PARAM, cp->id, CLIENT_ID_PARAM, DRIVER_ID, ACCOUNT_ID_PARAM, cp->id};
-    char **patt_arr = patterns;
+
+    /* patterns[1] its TITLE_PARAM, patterns[3] its ACCOUNT_ID_PARAM */
+    patterns[1] = patterns[3] = cp->id;
+    patt_arr = patterns;
     back_url = webauth(url, proxy, sPort, "", "", patt_arr, 8, cp->id);
 
     g_free(sPort);
@@ -636,9 +607,9 @@ xmlChar* get_req_function(xmlDocPtr reqXml)
 {
     xmlNodePtr rootNode = NULL;
     if (reqXml != NULL)
-	rootNode = xmlDocGetRootElement(reqXml);
+        rootNode = xmlDocGetRootElement(reqXml);
     if (rootNode != NULL)
-	return xmlGetProp(rootNode, BAD_CAST FUNCTION);
+        return xmlGetProp(rootNode, BAD_CAST FUNCTION);
     return NULL;
 }
 
@@ -664,24 +635,28 @@ void error_message(gchar* code, xmlDocPtr *doc, gchar* message, gchar* comment)
 
 void curl_set_options(CURL *c, const char* proxy, int port)
 {
+    gchar *curProxy = (gchar*)proxy;
+    gint curPort = port;
+    GConfClient* client;
+    gboolean hasProxy;
+    
+    if (curProxy == NULL)
+    {
+            /* try to get system proxy from gconf */
+            client = gconf_client_get_default ();
+            hasProxy = gconf_client_get_bool (client, GCONF_PROXY_USE, NULL);
+            msa_debug("%s:%d:%s: hasProxy=%d", __FILE__, __LINE__, __FUNCTION__, hasProxy);
+            if (hasProxy) {
+                curProxy = gconf_client_get_string (client, GCONF_PROXY_HOST, NULL);
+                curPort = gconf_client_get_int (client, GCONF_PROXY_PORT, NULL);
+                msa_debug("%s:%d:%s: host=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, curProxy, curPort);
+            }
+            g_object_unref(client);
+    }
+
     /* disable callbacks for working in multithreads */
     curl_easy_setopt(c, CURLOPT_NOSIGNAL, 1);
 
-    gchar *curProxy = (gchar*)proxy;
-    gint curPort = port;
-    if (curProxy == NULL)
-    {
-	/* try to get system proxy from gconf */
-	GConfClient *client = gconf_client_get_default ();
-	gboolean hasProxy = gconf_client_get_bool (client, GCONF_PROXY_USE, NULL);
-	msa_debug("%s:%d:%s: hasProxy=%d", __FILE__, __LINE__, __FUNCTION__, hasProxy);
-	if (hasProxy) {
-	    curProxy = gconf_client_get_string (client, GCONF_PROXY_HOST, NULL);
-	    curPort = gconf_client_get_int (client, GCONF_PROXY_PORT, NULL);
-	    msa_debug("%s:%d:%s: host=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, curProxy, curPort);
-	}
-	g_object_unref(client);
-    }
     curl_easy_setopt(c, CURLOPT_PROXY, curProxy);
     curl_easy_setopt(c, CURLOPT_PROXYPORT, curPort);
     curl_easy_setopt(c, CURLOPT_TIMEOUT, 120);
@@ -700,13 +675,11 @@ void curl_set_options(CURL *c, const char* proxy, int port)
  */
 int http_get(const char* url, const char* proxy, int port, char** header, gchar** body, int* data_size)
 {
-    global_get++;    
-    msa_debug("IN HTTP GET!!! %d\n", global_get);
-
     CURL* c;
     long code;
     char* type2;
     char* encoded_url = NULL;
+    CURLcode errornum;
     struct MemoryStruct chunk, chunk2;
     
     chunk.memory = NULL; 
@@ -715,6 +688,8 @@ int http_get(const char* url, const char* proxy, int port, char** header, gchar*
     chunk2.memory = NULL; 
     chunk2.size = 0;
 
+    msa_debug("IN HTTP GET!!! global_get=%d\n", global_get++);
+
     c = curl_easy_init();
 
     msa_debug("%s:%d:%s:url in http_get %s, proxy=%s, port=%d", __FILE__, __LINE__, __FUNCTION__, url, proxy, port);
@@ -726,29 +701,26 @@ int http_get(const char* url, const char* proxy, int port, char** header, gchar*
     /* disable callbacks for working in multithreads*/
     curl_easy_setopt(c, CURLOPT_NOSIGNAL, 1);
     curl_easy_setopt(c, CURLOPT_SSL_VERIFYPEER, 0);
-    
 
     curl_easy_setopt(c, CURLOPT_WRITEFUNCTION, WriteMemoryCallback);
     curl_easy_setopt(c, CURLOPT_HEADERFUNCTION, WriteMemoryCallback);
 
     curl_easy_setopt(c, CURLOPT_WRITEDATA, (void *)&chunk);
     curl_easy_setopt(c, CURLOPT_WRITEHEADER, (void *)&chunk2);
-    msa_debug("send request");
+    msa_debug("%s:%d:%s():send request", __FILE__, __LINE__, __FUNCTION__);
 
-    CURLcode curlResult = curl_easy_perform(c);
-    if ( curlResult != 0) {
-        g_warning("Can't perform the request\n");
-        g_debug("Curl CODE: %u", curlResult);
+    if ((errornum = curl_easy_perform(c)) != 0) {
+        g_warning("%s:%d:%s: Can't perform the request: (%u) %s", __FILE__, __LINE__, __FUNCTION__, errornum, curl_easy_strerror(errornum));
         curl_easy_cleanup(c);
         return 400;
     }
 
     free(encoded_url);
-    CURLcode ret = curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &code );
+    errornum = curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &code );
     msa_debug("CODE %ld", code);
 
-    /*type2 = g_malloc(sizeof(char)*50);*/
-    ret = curl_easy_getinfo(c, CURLINFO_CONTENT_TYPE, &type2 );
+    /* type2 = g_malloc(sizeof(char)*50); */
+    errornum = curl_easy_getinfo(c, CURLINFO_CONTENT_TYPE, &type2 );
     msa_debug("TYPE %s", type2);
 
     if (header != NULL) {
@@ -761,14 +733,14 @@ int http_get(const char* url, const char* proxy, int port, char** header, gchar*
 
     if (body != NULL) {
             *data_size = chunk.size;
-    	    *body = chunk.memory;
+            *body = chunk.memory;
     } else 
         if(chunk.memory)
             free(chunk.memory);
 
-    /*g_print("CONTENT  %s\n", *body);*/
+    /* g_print("CONTENT  %s\n", *body); */
 
-    /*g_free(type2);*/
+    /* g_free(type2); */
     curl_easy_cleanup(c);
 
     return code;
@@ -790,7 +762,7 @@ int http_post(const char* url, const char* proxy, int port, char* post_data, cha
 {
     CURL* c;
     long code;
-    CURLcode res;
+    CURLcode errornum;
     struct MemoryStruct chunk,chunk2;
 
     chunk.memory = NULL;
@@ -821,14 +793,13 @@ int http_post(const char* url, const char* proxy, int port, char* post_data, cha
     curl_easy_setopt(c, CURLOPT_WRITEHEADER, (void *)&chunk2);
     msa_debug("%s:%d:%s():send request", __FILE__, __LINE__, __FUNCTION__);
     
-    CURLcode errornum = curl_easy_perform(c);
-    if (errornum != 0) {
-        g_warning("%s:%d:%s: Can't perform the request: %s", __FILE__, __LINE__, __FUNCTION__, curl_easy_strerror(errornum));
+    if ((errornum = curl_easy_perform(c)) != 0) {
+        g_warning("%s:%d:%s: Can't perform the request: (%u) %s", __FILE__, __LINE__, __FUNCTION__, errornum, curl_easy_strerror(errornum));
         curl_easy_cleanup(c);
         return 400;
     }
     
-    res = curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &code );
+    errornum = curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &code );
     msa_debug("CODE %ld", code);
     msa_debug("HEADER\n  %s", chunk2.memory);    
     
@@ -843,7 +814,7 @@ int http_post(const char* url, const char* proxy, int port, char* post_data, cha
         *data_size = chunk.size;
         *body = g_strdup(chunk.memory);
         if(chunk.memory) 
-	    g_free(chunk.memory);
+            g_free(chunk.memory);
     }
     
     curl_easy_cleanup(c);
@@ -852,11 +823,17 @@ int http_post(const char* url, const char* proxy, int port, char* post_data, cha
 
 int http_upload_file(const char* url, const char* proxy, const int port, char** header, gchar** body, struct ProfileData *cp, struct UpFile *file)
 {
+    int i = 0;
     CURL *curl;
     CURLcode res;
     long code;
     struct MemoryStruct chunk,chunk2;
-    int i = 0;
+    struct curl_httppost *formpost=NULL;
+    struct curl_httppost *lastptr=NULL;
+    struct curl_slist *headerlist=NULL;
+    static const char buf[] = "Expect:";
+
+    MSA_UNUSED(cp)
 
     chunk.memory = NULL;
     chunk.size = 0;
@@ -864,11 +841,6 @@ int http_upload_file(const char* url, const char* proxy, const int port, char**
     chunk2.memory = NULL;
     chunk2.size = 0;
 
-    struct curl_httppost *formpost=NULL;
-    struct curl_httppost *lastptr=NULL;
-    struct curl_slist *headerlist=NULL;
-    static const char buf[] = "Expect:";
-
     curl_global_init(CURL_GLOBAL_ALL);
 
     /* Fill in the file upload field */
@@ -928,7 +900,7 @@ int http_upload_file(const char* url, const char* proxy, const int port, char**
         if (body != NULL) {
             *body = g_strdup(chunk.memory);
         if(chunk.memory) 
-	        g_free(chunk.memory);
+            g_free(chunk.memory);
         }
         /* always cleanup */
         curl_easy_cleanup(curl);
@@ -960,45 +932,40 @@ xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc)
 **/
 xmlXPathObject* xpath(gchar* req, xmlDocPtr doc)
 {
-	xmlXPathObject *Obj;
-	xmlXPathContextPtr Ctx;
-	
-	msa_debug("fb_xpath: %s", req);
+        xmlXPathObject *Obj;
+        xmlXPathContextPtr Ctx;
+        
+        msa_debug("xpath: %s", req);
 
     if (doc == NULL || req == NULL)
         return NULL;
 
-	Ctx = xmlXPathNewContext(doc);
-	
-	if (Ctx == NULL) {
-		msa_debug("fb_xpath: error wrong request format!");
-		return NULL;	
-	}
+        Ctx = xmlXPathNewContext(doc);
+        
+        if (Ctx == NULL) {
+            msa_debug("xpath: error wrong request format!");
+            return NULL;
+        }
 
-	Obj = xmlXPathEvalExpression(BAD_CAST req, Ctx);
+        Obj = xmlXPathEvalExpression(BAD_CAST req, Ctx);
 
+        msa_debug("xpath: end");
 
         xmlXPathFreeContext(Ctx);
-	msa_debug("fb_xpath: end");
 
-	return Obj;
+        return Obj;
 
 }
 
 void upfile_remove(struct UpFile *file)
 {
-    if (file != NULL){
-        if (file->name != NULL)
-	    g_free(file->name);
-        if (file->file_path != NULL)
-	    g_free(file->file_path);
-        if (file->file_name != NULL)
-	    g_free(file->file_name);
-        if (file->params != NULL)
-            g_strfreev(file->params);
-
-        free(file);
-        file = NULL;
-    }
+    if (file == NULL)
+        return;
+    g_free(file->name);
+    g_free(file->file_path);
+    g_free(file->file_name);
+    g_strfreev(file->params);
+    free(file);
+    file = NULL;
 }
 
